@@ -10,7 +10,8 @@
 
 #![no_std]
 #![deny(missing_docs)]
-#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, doc(auto_cfg))]
 
 //! Represents XMPP addresses, also known as JabberIDs (JIDs) for the [XMPP](https://xmpp.org/)
 //! protocol. A [`Jid`] can have between one and three parts in the form `node@domain/resource`:
@@ -101,10 +102,11 @@ fn domain_check(mut domain: &str) -> Result<Cow<'_, str>, Error> {
     }
 
     // Then if this is an IPv6 address.
-    if domain.starts_with('[') && domain.ends_with(']') {
-        if Ipv6Addr::from_str(&domain[1..domain.len() - 1]).is_ok() {
-            return Ok(Cow::Borrowed(domain));
-        }
+    if domain.starts_with('[')
+        && domain.ends_with(']')
+        && Ipv6Addr::from_str(&domain[1..domain.len() - 1]).is_ok()
+    {
+        return Ok(Cow::Borrowed(domain));
     }
 
     // idna can handle the root dot for us, but we still want to remove it for normalization
@@ -687,7 +689,7 @@ impl ToTokens for Jid {
     fn to_tokens(&self, tokens: &mut TokenStream) {
         let s = &self.normalized;
         tokens.extend(quote! {
-            ::jid::Jid::new(#s).unwrap()
+            jid::Jid::new(#s).unwrap()
         });
     }
 }
@@ -697,7 +699,7 @@ impl ToTokens for FullJid {
     fn to_tokens(&self, tokens: &mut TokenStream) {
         let s = &self.inner.normalized;
         tokens.extend(quote! {
-            ::jid::FullJid::new(#s).unwrap()
+            jid::FullJid::new(#s).unwrap()
         });
     }
 }
@@ -707,7 +709,7 @@ impl ToTokens for BareJid {
     fn to_tokens(&self, tokens: &mut TokenStream) {
         let s = &self.inner.normalized;
         tokens.extend(quote! {
-            ::jid::BareJid::new(#s).unwrap()
+            jid::BareJid::new(#s).unwrap()
         });
     }
 }
@@ -1145,19 +1147,19 @@ mod tests {
     fn minidom_into_attr() {
         let full = FullJid::new("a@b/c").unwrap();
         let elem = minidom::Element::builder("message", "jabber:client")
-            .attr("from", full.clone())
+            .attr("from".try_into().unwrap(), full.clone())
             .build();
         assert_eq!(elem.attr("from"), Some(full.to_string().as_str()));
 
         let bare = BareJid::new("a@b").unwrap();
         let elem = minidom::Element::builder("message", "jabber:client")
-            .attr("from", bare.clone())
+            .attr("from".try_into().unwrap(), bare.clone())
             .build();
         assert_eq!(elem.attr("from"), Some(bare.to_string().as_str()));
 
         let jid = Jid::from(bare.clone());
         let _elem = minidom::Element::builder("message", "jabber:client")
-            .attr("from", jid)
+            .attr("from".try_into().unwrap(), jid)
             .build();
         assert_eq!(elem.attr("from"), Some(bare.to_string().as_str()));
     }
